ncollpyde package
=================

Submodules
----------

ncollpyde.main module
---------------------

.. automodule:: ncollpyde.main
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: ncollpyde
   :members:
   :undoc-members:
   :show-inheritance:
